<?php
namespace Ak\Mail\Transport;

use Interop\Container\ContainerInterface;
use Laminas\Mail\Transport\TransportInterface;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Stvara novu instancu Sendgrid transporta.
 *
 * @package Ak\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mail
 */
final class SendgridFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param ContainerInterface $container
     * @param string $requestedName
     * @param null|array $options
     *
     * @return TransportInterface
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null): TransportInterface
    {
        $config = $container->get('config')['sendgrid'] ?? [];

        if (empty($config['api_key'])) {
            throw new ServiceNotCreatedException('Api ključ za sendgrid nije postavljen.');
        }

        return new Sendgrid($config['api_key']);
    }
}
