<?php /** @noinspection PhpUnused */
namespace Ak\Mail\Transport;

use Laminas\Mail\Transport\File;
use Laminas\Mail\Transport\InMemory;
use Laminas\Mail\Transport\Sendmail;
use Laminas\Mail\Transport\Smtp;
use Laminas\Mail\Transport\TransportInterface;
use Laminas\ServiceManager\AbstractPluginManager;
use Laminas\ServiceManager\Factory\InvokableFactory;

/**
 * Upravlja instancama mail transporta.
 *
 * @package Ak\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mail
 */
final class TransportPluginManager extends AbstractPluginManager
{
    const CONFIG_KEY = 'mail_transports';
    /** @var string  */
    protected $instanceOf = TransportInterface::class;
    /** @var array */
    protected $aliases = [
        'file'     => File::class,
        'inmemory' => InMemory::class,
        'sendgrid' => Sendgrid::class,
        'sendmail' => Sendmail::class,
        'smtp'     => Smtp::class,
    ];
    /** @var array */
    protected $factories = [
        File::class     => FileFactory::class,
        InMemory::class => InvokableFactory::class,
        Sendgrid::class => SendgridFactory::class,
        Sendmail::class => InvokableFactory::class,
        Smtp::class     => SmtpFactory::class,
    ];
}
