<?php
namespace AkTest\Mail\Transport;

use Ak\Mail\Transport\Sendgrid;
use Ak\Test\AbstractTestCase;
use AkTest\Mail\TestConfigProvider;
use Laminas\Mail\Transport\TransportInterface;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\PluginManagerInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Class SendgridTest
 *
 * @package AkTest\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mail
 */
final class SendgridTest extends AbstractTestCase
{
    public $configProviders = [
        TestConfigProvider::class,
    ];

    /**
     * @return void
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function testIsRegistered()
    {
        $container = $this->getContainer([
            'sendgrid' => [
                'api_key' => 'SOME_API_KEY',
            ],
        ]);

        $transports = $container->get('mail.transports');

        $this->assertContainerHasService($transports, [
            'sendgrid',
            Sendgrid::class,
        ], TransportInterface::class, true);
    }

    /**
     * @return void
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function testFactoryWillThrowExceptionWhenApiKeyNotSet()
    {
        $container = $this->getContainer([
            'sendgrid' => [
                'api_key' => null,
            ],
        ]);
        /** @var PluginManagerInterface $transports */
        $transports = $container->get('mail.transports');

        $this->expectException(ServiceNotCreatedException::class);
        $transports->get('sendgrid');
    }

    /**
     * @return void
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function testTransportIsPropertyConfigured()
    {
        $container = $this->getContainer([
            'sendgrid' => [
                'api_key' => 'SOME_API_KEY',
            ],
        ]);

        /** @var PluginManagerInterface $transports */
        $transports = $container->get('mail.transports');
        /** @var Sendgrid $transport */
        $transport = $transports->get('sendgrid');

        $options = $transport->getOptions();
        $this->assertEquals('smtp.sendgrid.net', $options->getName());
        $this->assertEquals('smtp.sendgrid.net', $options->getHost());
        $this->assertEquals(25, $options->getPort());
        $this->assertEquals('login', $options->getConnectionClass());

        $config = $options->getConnectionConfig();
        $this->assertArrayHasKey('username', $config);
        $this->assertEquals('apikey', $config['username']);
        $this->assertArrayHasKey('password', $config);
        $this->assertEquals('SOME_API_KEY', $config['password']);
    }
}
