<?php
namespace AkTest\Mail\Transport;

use Ak\Mail\Transport\TransportServiceAbstractFactory;
use Ak\Test\AbstractTestCase;
use AkTest\Mail\TestConfigProvider;
use Laminas\Mail\Transport\Sendmail;
use Laminas\Mail\Transport\Smtp;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Class TransportServiceAbstractFactoryTest
 *
 * @package AkTest\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mail
 */
final class TransportServiceAbstractFactoryTest extends AbstractTestCase
{
    public $configProviders = [
        TestConfigProvider::class,
    ];

    /**
     * @return void
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function testCanCreateTransportServices()
    {
        $container = $this->getContainer([
            'mail' => [
                'default_transport' => 'webshop',
                'transports' => [
                    'logging' => [
                        'name' => 'sendmail',
                    ],
                    'webshop' => [
                        'name' => 'smtp',
                        'options' => [
                            'name' => 'test-transport',
                            'host' => 'smtp.example.com',
                        ],
                    ],
                ],
            ],

            'dependencies' => [
                'abstract_factories' => [
                    TransportServiceAbstractFactory::class,
                ],
            ],
        ]);

        $this->assertTrue($container->has('mail'));

        /** @var Smtp $webshop */
        $webshop = $container->get('mail');
        $this->assertInstanceOf(Smtp::class, $webshop);
        $this->assertSame($webshop, $container->get('mail'));

        $this->assertTrue($container->has('mail.webshop'));
        $this->assertSame($webshop, $container->get('mail.webshop'));

        $options = $webshop->getOptions();
        $this->assertEquals('test-transport', $options->getName());
        $this->assertEquals('smtp.example.com', $options->getHost());

        $this->assertTrue($container->has('mail.logging'));
        $this->assertInstanceOf(Sendmail::class, $container->get('mail.logging'));
    }
}
